//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Job/JobResultsPresenter.h
//! @brief     Defines class JobResultsPresenter
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_JOB_JOBRESULTSPRESENTER_H
#define BORNAGAIN_GUI_VIEW_JOB_JOBRESULTSPRESENTER_H

#include "GUI/View/Common/ItemComboWidget.h"

class InstrumentItem;
class JobItem;
enum class JobViewActivity;

//! Presents results of job (JobItem) using stack of different widgets and combo box in the
//! right top corner of JobView, to switch between widgets.

class JobResultsPresenter : public ItemComboWidget {
    Q_OBJECT

public:
    explicit JobResultsPresenter(QWidget* parent = nullptr);

    void setItem(SessionItem* item) override;
    void setPresentation(const QString& presentationType) override;

public slots:
    void setPresentation(JobViewActivity activity);

protected:
    QString itemPresentation() const override;
    QStringList activePresentationList(SessionItem* item) override;
    QStringList presentationList(SessionItem* item) override;

private:
    QString defaultPresentationOfInstrument(InstrumentItem* instrumentItem);
    QStringList defaultActivePresentationsOfInstrument(InstrumentItem* instrumentItem);
    QString fitPresentationOfInstrument(InstrumentItem* instrumentItem);
    void notifyJobPropertyChanged(const QString& property);

private:
    JobViewActivity m_activity;
};

#endif // BORNAGAIN_GUI_VIEW_JOB_JOBRESULTSPRESENTER_H
