//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Projection/IntensityDataProjectionsWidget.cpp
//! @brief     Defines class IntensityDataProjectionsWidget
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Projection/IntensityDataProjectionsWidget.h"
#include "GUI/Model/Data/DataItemUtils.h"
#include "GUI/Model/Data/IntensityDataItem.h"
#include "GUI/Model/Data/ProjectionItems.h"
#include "GUI/View/Projection/ProjectionsEditor.h"
#include <QVBoxLayout>

IntensityDataProjectionsWidget::IntensityDataProjectionsWidget(QWidget* parent)
    : SessionItemWidget(parent), m_projectionsEditor(new ProjectionsEditor)
{
    auto* vlayout = new QVBoxLayout(this);
    vlayout->setMargin(0);
    vlayout->setSpacing(0);
    vlayout->addWidget(m_projectionsEditor);

    setLayout(vlayout);
}

QList<QAction*> IntensityDataProjectionsWidget::actionList()
{
    return m_projectionsEditor->topToolBarActions();
}

void IntensityDataProjectionsWidget::subscribeToItem()
{
    auto* container = projectionContainer(intensityDataItem());

    m_projectionsEditor->setContext(intensityDataItem()->model(), container->index(),
                                    intensityDataItem());
}

void IntensityDataProjectionsWidget::unsubscribeFromItem()
{
    m_projectionsEditor->resetContext();
}

IntensityDataItem* IntensityDataProjectionsWidget::intensityDataItem()
{
    return GUI::Model::DataItemUtils::intensityDataItem(currentItem());
}

ProjectionContainerItem*
IntensityDataProjectionsWidget::projectionContainer(IntensityDataItem* intensityItem)
{
    ASSERT(intensityItem);

    ProjectionContainerItem* containerItem = intensityItem->getOrCreateProjectionContainerItem();
    ASSERT(containerItem);
    return containerItem;
}
