//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/SampleDesigner/RealSpacePanel.h
//! @brief     Defines class RealSpacePanel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_REALSPACEPANEL_H
#define BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_REALSPACEPANEL_H

#include <QWidget>

class SampleModel;
class QItemSelectionModel;
class RealSpaceCanvas;
class QAction;
class QToolBar;
class MaterialModel;

//! Panel to show 3D view of sample. Contains toolbar and RealSpaceCanvas

class RealSpacePanel : public QWidget {
    Q_OBJECT

public:
    RealSpacePanel(const MaterialModel* materialModel, SampleModel* sampleModel, QWidget* parent);

    QSize sizeHint() const override;
    RealSpaceCanvas* canvas();

    bool isViewLocked() const;
    void setLockViewActionVisible(bool visible);

private:
    RealSpaceCanvas* m_canvas;
    QAction* m_lockViewAction;
    QToolBar* m_toolbar;
};

#endif // BORNAGAIN_GUI_VIEW_SAMPLEDESIGNER_REALSPACEPANEL_H
